##  [](https://api-docs.portainer.io/?edition=ee&version=2.39.0#tag/endpoints/operation/EndpointCreateGlobalKey)Create or retrieve the endpoint for an EdgeID
### Responses
**200**
Success
**400**
Invalid request
**500**
Server error
post/endpoints/global-key
https://api-docs.portainer.io/api/endpoints/global-key
